@@ -309,7 +309,7 @@ def allocate_stack():
         return _allocate_snapshot(payload)
     elif docker.is_deployed(payload['_file'], params):
         return _allocate_deployed(payload, params)
-    elif not docker.is_removed(payload['_file']):
+    elif '_file_path' in payload:
         return _allocate_new(payload)
     else:
         return "Could not start " + payload['_file']
@@ -319,8 +319,8 @@ Query the deployed applications.
 """
 @app.route('/deployed', methods=['GET'])
 def query_deployed():
-    mode = request.form['mode']
-    conf = request.form['conf']
+    mode = request.args['mode']
+    conf = request.args['conf']
     params = docker._get_deploy_params(mode, conf)
 
     return docker.query_deployed(params)
@@ -330,8 +330,11 @@ Query the stacks.
 """
 @app.route('/query', methods=['GET'])
 def query_stacks():
-    return docker.query_stacks()
-
+    if 'constraints' in request.args:
+        constraints = json.loads(request.args['constraints'])
+        return docker.query_stacks(constraints)
+    else:
+        return docker.query_stacks()
 """
 Query the snapshots
 """
